@@ -10,8 +10,10 @@ class NovaClient(Client):
         self.api.servers.actions["force_delete"] = {"method": "DELETE", "url": "servers/{}"}
         self.api.servers.actions["get"] = {"method": "GET", "url": "servers/{}"}
         self.api.servers.actions["list"] = {"method": "GET", "url": "servers/detail"}
+        self.api.servers.actions["run_action"] = {"method": "POST", "url": "servers/{}/action"}
         self.api.servers.add_action("force_delete")
         self.api.servers.add_action("get")
+        self.api.servers.add_action("run_action")
         self.api.flavors.actions["list"] = {"method": "GET", "url": "flavors/detail"}
         self.api.metadata.actions['get'] = {"method": "GET", "url": "servers/{}/metadata"}
         self.api.metadata.actions['set'] = {"method": "POST", "url": "servers/{}/metadata"}
